WebviewFlutterX5 class

Constructors

WebviewFlutterX5()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

canGetAndroidId(bool flag) Future<void>
canGetDeviceId(bool flag) Future<void>
canGetSubscriberId(bool flag) Future<void>
canUseTbsPlayer() Future<bool>
initX5({OnNeedPermissionCallback? needPermissionCallback}) Future<bool>
installX5({int? coreId, String? path}) Future<bool>
manualPhoneModel() Future<void>
manualPhoneSerial() Future<void>
openFile({required String filePath, bool local = false, String style = "0", String topBarBgColor = "#2CFC47", String? menuData}) Future<void>
openVideo({required String url, int screenMode = 103}) Future<void>
sdkVersion() Future<int>
setChooseFileMode(ChooseFileMode mode) Future<void>
setDownloadWithoutWifi({bool isWithoutWifi = false}) Future<void>
tbsVersion() Future<int>